@@ -315,6 +315,7 @@ class SitesInfo:
                                                 'remoteHostAttribute':'',
                                                 'stageFiles':True,
                                                 'passUseEnvironment':False,
+                                                'environment':[],
                                                 'arbitraryExecutableAllowed':True,
                                                 'executableClassificationsAllowed':['*'],
                                                 'members':[],
@@ -1065,6 +1066,7 @@ class SitesInfo:
       siteInfo['sharedUserSpace']                  = False
       siteInfo['stageFiles']                       = True
       siteInfo['passUseEnvironment']               = False
+      siteInfo['environment']                      = []
       siteInfo['logUserRemotely']                  = False
       siteInfo['remoteBatchAccount']               = ""
       siteInfo['remoteBatchSystem']                = ""
@@ -1122,6 +1124,7 @@ class SitesInfo:
          siteInfo['sharedUserSpace']               = False
       siteInfo['stageFiles']                       = site['stageFiles']
       siteInfo['passUseEnvironment']               = site['passUseEnvironment']
+      siteInfo['environment']                      = site['environment']
       siteInfo['logUserRemotely']                  = site['logUserRemotely']
       siteInfo['remoteBatchAccount']               = site['remoteBatchAccount']
       siteInfo['remoteBatchSystem']                = site['remoteBatchSystem']
